#!/bin/sh -e
# Copyright GD (C)2004
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Id: up.m4,v 1.9 2009/10/07 18:23:07 babolo Exp $

JNTROSTUP(mysqld,,mysqld-50dnl
,dnl
# jailup ${inclass} dir jailname jailaddr
#     where jailname - hostname for jail (see jail(2) hostname)
#           jailaddr - IP addr for jail (see jail(2) ip_number)
#           dir relative to ${JAILUPDIR} and ${JAILRODIR}
# installed ports/databases/mysql50-server useddnl
)

jdir="${1}"
jailsname="${2}"
jailsaddr="${3}"
main_dir="${JAILUPDIR}/${jdir}"
conf_dir="${JAILRODIR}/${jdir}"
if  [ -n "${CONFSHIFT}" ]; then
    conf_dir="${conf_dir}/${CONFSHIFT}"
fi

${mkdir} "${main_dir}" "${conf_dir}"
${up_mdir} "${main_dir}" ${MTREE}

ETCOPY(resolv.conf)

${up_libexe} "${main_dir}/libexec" <<- EOF
	ld-elf.so.1
	mysqld
EOF

${up_ldsh} <<- EOF | ${up_shlib} "${main_dir}/lib"
	${main_dir}/libexec/mysqld
EOF

${up_genlist} share/charsets/ ${MTREE} | ${up_data} "${main_dir}/share/" "${PREFIX}/share/mysql/charsets/"
CONFCOPY(my.cnf, "${TEMPLATE}")

${up_data} "${main_dir}/share/" "${PREFIX}/share/mysql/" <<- EOF
	errmsg.txt
	czech/errmsg.sys
	danish/errmsg.sys
	dutch/errmsg.sys
	english/errmsg.sys
	estonian/errmsg.sys
	french/errmsg.sys
	german/errmsg.sys
	greek/errmsg.sys
	hungarian/errmsg.sys
	italian/errmsg.sys
	japanese/errmsg.sys
	korean/errmsg.sys
	norwegian-ny/errmsg.sys
	norwegian/errmsg.sys
	polish/errmsg.sys
	portuguese/errmsg.sys
	romanian/errmsg.sys
	russian/errmsg.sys
	serbian/errmsg.sys
	slovak/errmsg.sys
	spanish/errmsg.sys
	swedish/errmsg.sys
	ukrainian/errmsg.sys
EOF

${up_acc} gr "${conf_dir}" <<- EOF
	wheel:*:0:
	daemon:*:1:mysql
	mysql:*:88:
	nogroup:*:65533:
	nobody:*:65534:
EOF

${up_acc} pwt "${conf_dir}" <<- EOF
	root:*:0:0::0:0:Charlie &:/:/dev/null/none
	mysql:*:88:88::0:0:MySQL Daemon:/dev/null/none:/dev/null/none
	nobody:*:65534:65534::0:0:Unprivileged user:/dev/null/none:/dev/null/none
EOF

${up_mtree} "${main_dir}" ${MTREE}
${mtree} -Ueqxp "${conf_dir}" << "EOF"
/set type=file uname=root gname=wheel mode=0644 flags=none
.				type=dir mode=0755
    group
    master.passwd		mode=0600
    my.cnf
EOF

${up_adc} "${JAILUPRC}" <<- EOF
	#${genclass}	${inclass}	${jdir}	${jailsname}	${jailsaddr}	0	88	88
EOF
      #####################################
      ####                             ####
      #### Begin of etc fill           ####
      ####                             ####
${up_adc} "${etcdir}/newsyslog.conf" <<- EOF
	#${main_dir}/var/log/my 	644  9     *	@01T00  Z ${main_dir}/var/run/${genclass}.pid
	#${main_dir}/var/log/err.err 	644  9     *	@01T00  Z ${main_dir}/var/run/${genclass}.pid
	#${main_dir}/var/log/slow 	644  9     *	@01T00  Z ${main_dir}/var/run/${genclass}.pid
EOF

${up_adc} "${etcdir}/fstab" <<- EOF
	#${conf_dir}		${main_dir}/etc	nullfs	ro,noexec	0 0
EOF
      ####                             ####
      #### End of etc fill             ####
      ####                             ####
      #####################################

mysql_db="${main_dir}/var/db/mysql"
mysql_script_dir="${PREFIX}/share/mysql"
mysql_bootstrap="${PREFIX}/libexec/mysqld --bootstrap --skip-name-resolve \
        --bind-address=${jailsaddr} --datadir=${mysql_db} --basedir=/usr/local \
        --max_allowed_packet=8M --net_buffer_length=16K --console"

if  [ ! -f "${mysql_db}/mysql/user.frm" ]; then
    (   echo 'USE mysql;';\
        ${cat} ${mysql_script_dir}/mysql_system_tables.sql;\
        ${cat} ${mysql_script_dir}/mysql_system_tables_data.sql;\
        ${cat} ${mysql_script_dir}/fill_help_tables.sql;\
        ${cat} ${mysql_script_dir}/mysql_fix_privilege_tables.sql;\
    ) | grep -v '@current_hostname' | ${mysql_bootstrap}
#   (echo 'USE mysql;'; echo 'DELETE FROM db WHERE Db LIKE "test%";') | ${mysql_bootstrap}
    chown -R mysql:mysql ${mysql_db}
fi
